@@ -185,7 +185,8 @@ class CreateBusinessCard(object):
                  relationships: Dict[str, Relationship], shipping_address: Optional[Address] = None,
                  ssn: Optional[str] = None, passport: Optional[str] = None, nationality: Optional[str] = None,
                  design: Optional[str] = None, idempotency_key: Optional[str] = None,
-                 tags: Optional[Dict[str, str]] = None):
+                 tags: Optional[Dict[str, str]] = None, limits: Optional[CardLevelLimits] = None,
+                 additional_embossed_text: Optional[str] = None, print_only_business_name: Optional[bool] = None):
         self.full_name = full_name
         self.date_of_birth = date_of_birth
         self.address = address
@@ -199,6 +200,9 @@ class CreateBusinessCard(object):
         self.idempotency_key = idempotency_key
         self.tags = tags
         self.relationships = relationships
+        self.limits = limits
+        self.additional_embossed_text = additional_embossed_text
+        self.print_only_business_name = print_only_business_name
 
     def to_json_api(self, _type: str) -> Dict:
         payload = {
@@ -236,6 +240,15 @@ class CreateBusinessCard(object):
         if self.tags:
             payload["data"]["attributes"]["tags"] = self.tags
 
+        if self.limits:
+            payload["data"]["attributes"]["limits"] = self.limits
+
+        if self.additional_embossed_text:
+            payload["data"]["attributes"]["additionalEmbossedText"] = self.additional_embossed_text
+
+        if self.print_only_business_name is not None:
+            payload["data"]["attributes"]["printOnlyBusinessName"] = self.print_only_business_name
+
         return payload
 
     def __repr__(self):
@@ -284,7 +297,7 @@ class CreateBusinessVirtualCard(object):
     def __init__(self, full_name: FullName, date_of_birth: date, address: Address, phone: Phone, email: str,
                  relationships: Dict[str, Relationship], ssn: Optional[str] = None, passport: Optional[str] = None,
                  nationality: Optional[str] = None, idempotency_key: Optional[str] = None,
-                 tags: Optional[Dict[str, str]] = None):
+                 tags: Optional[Dict[str, str]] = None, limits: Optional[CardLevelLimits] = None):
         self.full_name = full_name
         self.date_of_birth = date_of_birth
         self.address = address
@@ -296,6 +309,7 @@ class CreateBusinessVirtualCard(object):
         self.idempotency_key = idempotency_key
         self.tags = tags
         self.relationships = relationships
+        self.limits = limits
 
     def to_json_api(self, _type: str) -> Dict:
         payload = {
@@ -327,6 +341,9 @@ class CreateBusinessVirtualCard(object):
         if self.tags:
             payload["data"]["attributes"]["tags"] = self.tags
 
+        if self.limits:
+            payload["data"]["attributes"]["limits"] = self.limits
+
         return payload
 
     def __repr__(self):
@@ -381,7 +398,7 @@ class PatchIndividualDebitCard(object):
 class PatchBusinessCard(object):
     def __init__(self, card_id: str, shipping_address: Optional[Address] = None, address: Optional[Address] = None,
                  phone: Optional[Phone] = None, email: Optional[str] = None, design: Optional[str] = None,
-                 tags: Optional[Dict[str, str]] = None):
+                 tags: Optional[Dict[str, str]] = None, limits: Optional[CardLevelLimits] = None):
         self.card_id = card_id
         self.shipping_address = shipping_address
         self.address = address
@@ -389,6 +406,7 @@ class PatchBusinessCard(object):
         self.email = email
         self.design = design
         self.tags = tags
+        self.limits = limits
 
     def to_json_api(self, _type: str = "businessDebitCard") -> Dict:
         payload = {
@@ -416,6 +434,9 @@ class PatchBusinessCard(object):
         if self.tags:
             payload["data"]["attributes"]["tags"] = self.tags
 
+        if self.limits:
+            payload["data"]["attributes"]["limits"] = self.limits
+
         return payload
 
     def __repr__(self):
@@ -456,12 +477,13 @@ class PatchIndividualVirtualDebitCard(object):
 class PatchBusinessVirtualCard(object):
     def __init__(self, card_id: str, address: Optional[Address] = None, phone: Optional[Phone] = None,
                  email: Optional[str] = None, tags: Optional[Dict[str, str]] = None,
-                 _type: str = "businessVirtualDebitCard"):
+                 _type: str = "businessVirtualDebitCard", limits: Optional[CardLevelLimits] = None):
         self.card_id = card_id
         self.address = address
         self.phone = phone
         self.email = email
         self.tags = tags
+        self.limits = limits
 
     def to_json_api(self, _type: str = "businessVirtualDebitCard") -> Dict:
         payload = {
@@ -483,6 +505,9 @@ class PatchBusinessVirtualCard(object):
         if self.tags:
             payload["data"]["attributes"]["tags"] = self.tags
 
+        if self.limits:
+            payload["data"]["attributes"]["limits"] = self.limits
+
         return payload
 
 
